@@ -9,7 +9,7 @@ use Mojo::Util;
 use constant DEBUG => $ENV{MOJO_WEBPACK_DEBUG} && 1;
 
 our @CARP_NOT;
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 has engine => undef;
 
@@ -290,7 +290,7 @@ this:
     "relative/output.js" => {               # Key is a friendly name, withouc checksum
       ext      => 'css',                    # File extension
       helper   => 'javascript',             # Mojolicious helper used to render the asset
-      rel_name => "relatibe/output.xyz.js", # Relative filename with checksum
+      rel_name => "relative/output.xyz.js", # Relative filename with checksum
     },
     ...
   }
